==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingPlc.md <==
# AwsIoTThingPlc


```text
aws-20210730/Resource/LoT/AwsIoTThingPlc
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')
```



| Illustration | AwsIoTThingPlc | AwsIoTThingPlcCard | AwsIoTThingPlcGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingPlc.png) | ![illustration for AwsIoTThingPlc](../../../aws-20210730/Resource/LoT/AwsIoTThingPlc.Local.png) | ![illustration for AwsIoTThingPlcCard](../../../aws-20210730/Resource/LoT/AwsIoTThingPlcCard.Local.png) | ![illustration for AwsIoTThingPlcGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingPlcGroup.Local.png) |




## AwsIoTThingPlc

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlc
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlc('AwsIoTThingPlc', 'Aws Io T Thing Plc', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlc
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlc('AwsIoTThingPlc', 'Aws Io T Thing Plc', 'an optional tech label')
@enduml
```

## AwsIoTThingPlcCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcCard
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcCard('AwsIoTThingPlcCard', 'Aws Io T Thing Plc Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcCard
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcCard('AwsIoTThingPlcCard', 'Aws Io T Thing Plc Card', 'an optional description')
@enduml
```

## AwsIoTThingPlcGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcGroup
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcGroup('AwsIoTThingPlcGroup', 'Aws Io T Thing Plc Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcGroup
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcGroup('AwsIoTThingPlcGroup', 'Aws Io T Thing Plc Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingPlc.md <==
# AwsIoTThingPlc


```text
aws-20210730/Resource/LoT/AwsIoTThingPlc
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')
```



| Illustration | AwsIoTThingPlc | AwsIoTThingPlcCard | AwsIoTThingPlcGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingPlc.png) | ![illustration for AwsIoTThingPlc](../../../aws-20210730/Resource/LoT/AwsIoTThingPlc.Local.png) | ![illustration for AwsIoTThingPlcCard](../../../aws-20210730/Resource/LoT/AwsIoTThingPlcCard.Local.png) | ![illustration for AwsIoTThingPlcGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingPlcGroup.Local.png) |




## AwsIoTThingPlc

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlc
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlc('AwsIoTThingPlc', 'Aws Io T Thing Plc', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlc
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlc('AwsIoTThingPlc', 'Aws Io T Thing Plc', 'an optional tech label')
@enduml
```

## AwsIoTThingPlcCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcCard
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcCard('AwsIoTThingPlcCard', 'Aws Io T Thing Plc Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcCard
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcCard('AwsIoTThingPlcCard', 'Aws Io T Thing Plc Card', 'an optional description')
@enduml
```

## AwsIoTThingPlcGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcGroup
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcGroup('AwsIoTThingPlcGroup', 'Aws Io T Thing Plc Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingPlcGroup
include('aws-20210730/Resource/LoT/AwsIoTThingPlc')

' renders the element
AwsIoTThingPlcGroup('AwsIoTThingPlcGroup', 'Aws Io T Thing Plc Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
